# ksubscribe
Python-Event-Based-Programming-Methodology

<br/><br/>
This is a library that help python coder to run event-based methodology.
<br/><br/>
You can subscribe an event from object to another object. Ksubscribe library is designed with _**Singleton design pattern**_. So, if you create more that one Ksubscribe object, the all object is actually **same object**.
<br/><br/>:exclamation::exclamation:<br/>
Subscriber class must have _inform or _informWithParameters functions. You can see the examples in examples.

<br/><br/>
You can check [example usage](https://github.com/bossman48/ksubscribe-example-usage#in-this-example-usage-of-ksubscribe-we-have-master-and-slave-class)

<br/><br/>
If you have any question, send mail to [me](kuzucu48@gmail.com)



